[libgdata] General API cleanup



commit 172ac2c22c853841c2edfb405976bc3f962586fb
Author: Philip Withnall <philip tecnocode co uk>
Date:   Wed Apr 22 17:38:33 2009 +0100

    General API cleanup
    
    Added gdata_service_get_proxy and a corresponding GDataService:proxy-uri
    property, which proxies SoupSession's proxy-uri property.
    Renamed gdata_query_get_strict and gdata_query_set_strict to
    gdata_query_is_strict and gdata_query_set_is_strict, respectively; also
    renamed the corresponding :strict property to :is-strict.
    Renamed the boxed type function for GTimeVal to gdata_g_time_val_get_type,
    to avoid namespace clashes.
    Added some functions to the symbols file which were missing.
---
 docs/reference/gdata-sections.txt                 |    7 ++-
 gdata/gdata-entry.c                               |    4 +-
 gdata/gdata-feed.c                                |    2 +-
 gdata/gdata-query.c                               |   56 ++++++++++----------
 gdata/gdata-query.h                               |    4 +-
 gdata/gdata-service.c                             |   55 +++++++++++++++++++-
 gdata/gdata-service.h                             |    1 +
 gdata/gdata-types.c                               |    7 ++-
 gdata/gdata-types.h                               |    4 +-
 gdata/gdata.symbols                               |   14 +++--
 gdata/services/calendar/gdata-calendar-calendar.c |    2 +-
 gdata/services/calendar/gdata-calendar-calendar.h |    1 -
 gdata/services/calendar/gdata-calendar-event.c    |    6 +-
 gdata/services/calendar/gdata-calendar-query.c    |    8 ++--
 gdata/services/contacts/gdata-contacts-contact.c  |    2 +-
 gdata/services/youtube/gdata-youtube-video.c      |    2 +-
 16 files changed, 116 insertions(+), 59 deletions(-)

diff --git a/docs/reference/gdata-sections.txt b/docs/reference/gdata-sections.txt
index de8125c..36dfa74 100644
--- a/docs/reference/gdata-sections.txt
+++ b/docs/reference/gdata-sections.txt
@@ -7,7 +7,6 @@ GDataServiceError
 GDataAuthenticationError
 GDataParserError
 GDataQueryProgressCallback
-gdata_service_set_proxy
 gdata_service_authenticate
 gdata_service_authenticate_async
 gdata_service_authenticate_finish
@@ -21,6 +20,8 @@ gdata_service_delete_entry
 gdata_service_get_client_id
 gdata_service_get_username
 gdata_service_get_password
+gdata_service_get_proxy
+gdata_service_set_proxy
 <SUBSECTION Standard>
 GDATA_SERVICE
 GDATA_IS_SERVICE
@@ -72,8 +73,8 @@ gdata_query_get_start_index
 gdata_query_set_start_index
 gdata_query_get_max_results
 gdata_query_set_max_results
-gdata_query_get_strict
-gdata_query_set_strict
+gdata_query_is_strict
+gdata_query_set_is_strict
 <SUBSECTION Standard>
 gdata_query_get_type
 GDATA_QUERY
diff --git a/gdata/gdata-entry.c b/gdata/gdata-entry.c
index f97794f..9eef16a 100644
--- a/gdata/gdata-entry.c
+++ b/gdata/gdata-entry.c
@@ -109,12 +109,12 @@ gdata_entry_class_init (GDataEntryClass *klass)
 	g_object_class_install_property (gobject_class, PROP_UPDATED,
 				g_param_spec_boxed ("updated",
 					"Updated", "The last update time for this entry.",
-					G_TYPE_TIME_VAL,
+					GDATA_TYPE_G_TIME_VAL,
 					G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 	g_object_class_install_property (gobject_class, PROP_PUBLISHED,
 				g_param_spec_boxed ("published",
 					"Published", "The time this entry was published.",
-					G_TYPE_TIME_VAL,
+					GDATA_TYPE_G_TIME_VAL,
 					G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 	g_object_class_install_property (gobject_class, PROP_CONTENT,
 				g_param_spec_string ("content",
diff --git a/gdata/gdata-feed.c b/gdata/gdata-feed.c
index bcfc489..5fd9b90 100644
--- a/gdata/gdata-feed.c
+++ b/gdata/gdata-feed.c
@@ -157,7 +157,7 @@ gdata_feed_class_init (GDataFeedClass *klass)
 	g_object_class_install_property (gobject_class, PROP_UPDATED,
 				g_param_spec_boxed ("updated",
 					"Updated", "The time the feed was last updated.",
-					G_TYPE_TIME_VAL,
+					GDATA_TYPE_G_TIME_VAL,
 					G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 	/**
diff --git a/gdata/gdata-query.h b/gdata/gdata-query.h
index 99638c0..22f7440 100644
--- a/gdata/gdata-query.h
+++ b/gdata/gdata-query.h
@@ -80,8 +80,8 @@ void gdata_query_get_published_max (GDataQuery *self, GTimeVal *published_max);
 void gdata_query_set_published_max (GDataQuery *self, GTimeVal *published_max);
 gint gdata_query_get_start_index (GDataQuery *self);
 void gdata_query_set_start_index (GDataQuery *self, gint start_index);
-gboolean gdata_query_get_strict (GDataQuery *self);
-void gdata_query_set_strict (GDataQuery *self, gboolean strict);
+gboolean gdata_query_is_strict (GDataQuery *self);
+void gdata_query_set_is_strict (GDataQuery *self, gboolean is_strict);
 gint gdata_query_get_max_results (GDataQuery *self);
 void gdata_query_set_max_results (GDataQuery *self, gint max_results);
 const gchar *gdata_query_get_entry_id (GDataQuery *self);
diff --git a/gdata/gdata-service.c b/gdata/gdata-service.c
index 3cb7ed5..7f010cd 100644
--- a/gdata/gdata-service.c
+++ b/gdata/gdata-service.c
@@ -37,6 +37,7 @@
 #include "gdata-service.h"
 #include "gdata-private.h"
 #include "gdata-marshal.h"
+#include "gdata-types.h"
 
 /* The default e-mail domain to use for usernames */
 #define EMAIL_DOMAIN "gmail.com"
@@ -61,6 +62,7 @@ static gboolean real_parse_authentication_response (GDataService *self, guint st
 static void real_append_query_headers (GDataService *self, SoupMessage *message);
 static void real_parse_error_response (GDataService *self, guint status, const gchar *reason_phrase,
 				       const gchar *response_body, gint length, GError **error);
+static void notify_proxy_uri_cb (GObject *gobject, GParamSpec *pspec, GObject *self);
 
 struct _GDataServicePrivate {
 	SoupSession *session;
@@ -76,7 +78,8 @@ enum {
 	PROP_CLIENT_ID = 1,
 	PROP_USERNAME,
 	PROP_PASSWORD,
-	PROP_AUTHENTICATED
+	PROP_AUTHENTICATED,
+	PROP_PROXY_URI
 };
 
 enum {
@@ -154,6 +157,17 @@ gdata_service_class_init (GDataServiceClass *klass)
 					G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 
 	/**
+	 * GDataService:proxy-uri:
+	 *
+	 * The proxy URI used internally for all Internet requests.
+	 **/
+	g_object_class_install_property (gobject_class, PROP_PROXY_URI,
+				g_param_spec_boxed ("proxy-uri",
+					"Proxy URI", "The proxy URI used internally for all Internet requests.",
+					SOUP_TYPE_URI,
+					G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
+
+	/**
 	 * GDataService::captcha-challenge:
 	 * @service: the #GDataService which received the challenge
 	 * @uri: the URI of the CAPTCHA image to be used
@@ -178,6 +192,9 @@ gdata_service_init (GDataService *self)
 {
 	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GDATA_TYPE_SERVICE, GDataServicePrivate);
 	self->priv->session = soup_session_sync_new ();
+
+	/* Proxy the SoupSession's proxy-uri property */
+	g_signal_connect (self->priv->session, "notify::proxy-uri", (GCallback) notify_proxy_uri_cb, self);
 }
 
 static void
@@ -225,6 +242,9 @@ gdata_service_get_property (GObject *object, guint property_id, GValue *value, G
 		case PROP_AUTHENTICATED:
 			g_value_set_boolean (value, priv->authenticated);
 			break;
+		case PROP_PROXY_URI:
+			g_value_set_boxed (value, gdata_service_get_proxy (GDATA_SERVICE (object)));
+			break;
 		default:
 			/* We don't have any other property... */
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -241,6 +261,9 @@ gdata_service_set_property (GObject *object, guint property_id, const GValue *va
 		case PROP_CLIENT_ID:
 			priv->client_id = g_value_dup_string (value);
 			break;
+		case PROP_PROXY_URI:
+			gdata_service_set_proxy (GDATA_SERVICE (object), g_value_get_boxed (value));
+			break;
 		default:
 			/* We don't have any other property... */
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -1171,6 +1194,33 @@ gdata_service_delete_entry (GDataService *self, GDataEntry *entry, GCancellable
 	return TRUE;
 }
 
+static void
+notify_proxy_uri_cb (GObject *gobject, GParamSpec *pspec, GObject *self)
+{
+	g_object_notify (self, "proxy-uri");
+}
+
+/**
+ * gdata_service_get_proxy:
+ * @self: a #GDataService
+ *
+ * Gets the proxy URI on the #GDataService's #SoupSession.
+ *
+ * Return value: the proxy URI, or %NULL
+ **/
+SoupURI *
+gdata_service_get_proxy (GDataService *self)
+{
+	SoupURI *proxy_uri;
+
+	g_return_val_if_fail (GDATA_IS_SERVICE (self), NULL);
+
+	g_object_get (self->priv->session, SOUP_SESSION_PROXY_URI, &proxy_uri, NULL);
+	g_object_unref (proxy_uri); /* remove the ref added by g_object_get */
+
+	return proxy_uri;
+}
+
 /**
  * gdata_service_set_proxy:
  * @self: a #GDataService
@@ -1183,7 +1233,8 @@ void
 gdata_service_set_proxy (GDataService *self, SoupURI *proxy_uri)
 {
 	g_return_if_fail (GDATA_IS_SERVICE (self));
-	g_object_set (self->priv->session, SOUP_SESSION_PROXY_URI, proxy_uri, NULL); 
+	g_object_set (self->priv->session, SOUP_SESSION_PROXY_URI, proxy_uri, NULL);
+	g_object_notify (G_OBJECT (self), "proxy-uri");
 }
 
 /**
diff --git a/gdata/gdata-service.h b/gdata/gdata-service.h
index b6cb2df..5bb8c78 100644
--- a/gdata/gdata-service.h
+++ b/gdata/gdata-service.h
@@ -173,6 +173,7 @@ GDataEntry *gdata_service_update_entry (GDataService *self, GDataEntry *entry, G
 gboolean gdata_service_delete_entry (GDataService *self, GDataEntry *entry, GCancellable *cancellable, GError **error);
 /* TODO: async version */
 
+SoupURI *gdata_service_get_proxy (GDataService *self);
 void gdata_service_set_proxy (GDataService *self, SoupURI *proxy_uri);
 
 gboolean gdata_service_is_authenticated (GDataService *self);
diff --git a/gdata/gdata-types.c b/gdata/gdata-types.c
index 8f90eb7..2849603 100644
--- a/gdata/gdata-types.c
+++ b/gdata/gdata-types.c
@@ -21,23 +21,24 @@
 #include <glib-object.h>
 #include <string.h>
 #include <stdlib.h>
+#include <libsoup/soup.h>
 
 #include "gdata-types.h"
 
 static gpointer
-g_time_val_copy (gpointer time_val)
+gdata_g_time_val_copy (gpointer time_val)
 {
 	return g_memdup (time_val, sizeof (GTimeVal));
 }
 
 GType
-g_time_val_get_type (void)
+gdata_g_time_val_get_type (void)
 {
 	static GType type_id = 0;
 
 	if (type_id == 0) {
 		type_id = g_boxed_type_register_static (g_intern_static_string ("GTimeVal"),
-							(GBoxedCopyFunc) g_time_val_copy,
+							(GBoxedCopyFunc) gdata_g_time_val_copy,
 							(GBoxedFreeFunc) g_free);
 	}
 
diff --git a/gdata/gdata-types.h b/gdata/gdata-types.h
index ea22bb4..f187e33 100644
--- a/gdata/gdata-types.h
+++ b/gdata/gdata-types.h
@@ -24,8 +24,8 @@
 
 G_BEGIN_DECLS
 
-#define G_TYPE_TIME_VAL (g_time_val_get_type ())
-GType g_time_val_get_type (void) G_GNUC_CONST;
+#define GDATA_TYPE_G_TIME_VAL (gdata_g_time_val_get_type ())
+GType gdata_g_time_val_get_type (void) G_GNUC_CONST;
 
 typedef struct {
 	guint16 red;
diff --git a/gdata/gdata.symbols b/gdata/gdata.symbols
index cdc1eac..44de79a 100644
--- a/gdata/gdata.symbols
+++ b/gdata/gdata.symbols
@@ -1,4 +1,5 @@
 gdata_color_get_type
+gdata_color_from_hexadecimal
 gdata_entry_get_type
 gdata_entry_new
 gdata_entry_new_from_xml
@@ -46,6 +47,7 @@ gdata_service_query_finish
 gdata_service_insert_entry
 gdata_service_update_entry
 gdata_service_delete_entry
+gdata_service_get_proxy
 gdata_service_set_proxy
 gdata_service_is_authenticated
 gdata_service_get_client_id
@@ -74,15 +76,16 @@ gdata_query_get_published_max
 gdata_query_set_published_max
 gdata_query_get_start_index
 gdata_query_set_start_index
-gdata_query_get_strict
-gdata_query_set_strict
+gdata_query_is_strict
+gdata_query_set_is_strict
 gdata_query_get_max_results
 gdata_query_set_max_results
 gdata_query_get_entry_id
 gdata_query_set_entry_id
 gdata_query_get_etag
 gdata_query_set_etag
-g_time_val_get_type
+gdata_g_time_val_get_type
+gdata_soup_uri_get_type
 gdata_category_new
 gdata_category_free
 gdata_link_new
@@ -218,8 +221,8 @@ gdata_calendar_query_get_start_min
 gdata_calendar_query_set_start_min
 gdata_calendar_query_get_start_max
 gdata_calendar_query_set_start_max
-gdata_calendar_query_get_ctz
-gdata_calendar_query_set_ctz
+gdata_calendar_query_get_timezone
+gdata_calendar_query_set_timezone
 gdata_calendar_service_get_type
 gdata_calendar_service_new
 gdata_calendar_service_query_all_calendars
@@ -250,6 +253,7 @@ gdata_gd_organization_new
 gdata_gd_organization_free
 gdata_media_expression_get_type
 gdata_parser_error_get_type
+gdata_parser_error_quark
 gdata_contacts_service_get_type
 gdata_contacts_service_new
 gdata_contacts_service_query_contacts
diff --git a/gdata/services/calendar/gdata-calendar-calendar.c b/gdata/services/calendar/gdata-calendar-calendar.c
index 061fc55..77fccd0 100644
--- a/gdata/services/calendar/gdata-calendar-calendar.c
+++ b/gdata/services/calendar/gdata-calendar-calendar.c
@@ -166,7 +166,7 @@ gdata_calendar_calendar_class_init (GDataCalendarCalendarClass *klass)
 	g_object_class_install_property (gobject_class, PROP_EDITED,
 				g_param_spec_boxed ("edited",
 					"Edited", "The last time the calendar was edited.",
-					G_TYPE_TIME_VAL,
+					GDATA_TYPE_G_TIME_VAL,
 					G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 }
 
diff --git a/gdata/services/calendar/gdata-calendar-calendar.h b/gdata/services/calendar/gdata-calendar-calendar.h
index 46e98c7..d909f84 100644
--- a/gdata/services/calendar/gdata-calendar-calendar.h
+++ b/gdata/services/calendar/gdata-calendar-calendar.h
@@ -74,7 +74,6 @@ gboolean gdata_calendar_calendar_is_selected (GDataCalendarCalendar *self);
 void gdata_calendar_calendar_set_is_selected (GDataCalendarCalendar *self, gboolean is_selected);
 const gchar *gdata_calendar_calendar_get_access_level (GDataCalendarCalendar *self);
 void gdata_calendar_calendar_get_edited (GDataCalendarCalendar *self, GTimeVal *edited);
-void gdata_calendar_calendar_set_edited (GDataCalendarCalendar *self, GTimeVal *edited);
 
 G_END_DECLS
 
diff --git a/gdata/services/calendar/gdata-calendar-event.c b/gdata/services/calendar/gdata-calendar-event.c
index a417f46..216bb33 100644
--- a/gdata/services/calendar/gdata-calendar-event.c
+++ b/gdata/services/calendar/gdata-calendar-event.c
@@ -94,7 +94,7 @@ gdata_calendar_event_class_init (GDataCalendarEventClass *klass)
 	g_object_class_install_property (gobject_class, PROP_EDITED,
 				g_param_spec_boxed ("edited",
 					"Edited", "TODO",
-					G_TYPE_TIME_VAL,
+					GDATA_TYPE_G_TIME_VAL,
 					G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 	g_object_class_install_property (gobject_class, PROP_EVENT_STATUS,
 				g_param_spec_string ("event-status",
@@ -124,12 +124,12 @@ gdata_calendar_event_class_init (GDataCalendarEventClass *klass)
 	g_object_class_install_property (gobject_class, PROP_START_TIME,
 				g_param_spec_boxed ("start-time",
 					"Start time", "TODO",
-					G_TYPE_TIME_VAL,
+					GDATA_TYPE_G_TIME_VAL,
 					G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 	g_object_class_install_property (gobject_class, PROP_END_TIME,
 				g_param_spec_boxed ("end-time",
 					"End time", "TODO",
-					G_TYPE_TIME_VAL,
+					GDATA_TYPE_G_TIME_VAL,
 					G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 	/* TODO: when-value is a stupid name */
 	g_object_class_install_property (gobject_class, PROP_WHEN_VALUE,
diff --git a/gdata/services/calendar/gdata-calendar-query.c b/gdata/services/calendar/gdata-calendar-query.c
index 7cb96cc..5f69e38 100644
--- a/gdata/services/calendar/gdata-calendar-query.c
+++ b/gdata/services/calendar/gdata-calendar-query.c
@@ -116,7 +116,7 @@ gdata_calendar_query_class_init (GDataCalendarQueryClass *klass)
 	g_object_class_install_property (gobject_class, PROP_RECURRENCE_EXPANSION_START,
 				g_param_spec_boxed ("recurrence-expansion-start",
 					"Recurrence expansion start", "Specifies beginning of time period for which to expand recurring events.",
-					G_TYPE_TIME_VAL,
+					GDATA_TYPE_G_TIME_VAL,
 					G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 	/**
@@ -127,7 +127,7 @@ gdata_calendar_query_class_init (GDataCalendarQueryClass *klass)
 	g_object_class_install_property (gobject_class, PROP_RECURRENCE_EXPANSION_END,
 				g_param_spec_boxed ("recurrence-expansion-end",
 					"Recurrence expansion end", "Specifies end of time period for which to expand recurring events.",
-					G_TYPE_TIME_VAL,
+					GDATA_TYPE_G_TIME_VAL,
 					G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 	/**
@@ -166,7 +166,7 @@ gdata_calendar_query_class_init (GDataCalendarQueryClass *klass)
 	g_object_class_install_property (gobject_class, PROP_START_MIN,
 				g_param_spec_boxed ("start-min",
 					"Start min", "A timespan such that only events that are within the timespan are returned.",
-					G_TYPE_TIME_VAL,
+					GDATA_TYPE_G_TIME_VAL,
 					G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 	/**
@@ -182,7 +182,7 @@ gdata_calendar_query_class_init (GDataCalendarQueryClass *klass)
 	g_object_class_install_property (gobject_class, PROP_START_MAX,
 				g_param_spec_boxed ("start-max",
 					"Start max", "A timespan such that only events that are within the timespan are returned.",
-					G_TYPE_TIME_VAL,
+					GDATA_TYPE_G_TIME_VAL,
 					G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 	/**
diff --git a/gdata/services/contacts/gdata-contacts-contact.c b/gdata/services/contacts/gdata-contacts-contact.c
index 6dd468e..d57fdd8 100644
--- a/gdata/services/contacts/gdata-contacts-contact.c
+++ b/gdata/services/contacts/gdata-contacts-contact.c
@@ -99,7 +99,7 @@ gdata_contacts_contact_class_init (GDataContactsContactClass *klass)
 	g_object_class_install_property (gobject_class, PROP_EDITED,
 				g_param_spec_boxed ("edited",
 					"Edited", "The last time the contact was edited.",
-					G_TYPE_TIME_VAL,
+					GDATA_TYPE_G_TIME_VAL,
 					G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 
 	/**
diff --git a/gdata/services/youtube/gdata-youtube-video.c b/gdata/services/youtube/gdata-youtube-video.c
index fb6222e..01970ff 100644
--- a/gdata/services/youtube/gdata-youtube-video.c
+++ b/gdata/services/youtube/gdata-youtube-video.c
@@ -346,7 +346,7 @@ gdata_youtube_video_class_init (GDataYouTubeVideoClass *klass)
 	g_object_class_install_property (gobject_class, PROP_UPLOADED,
 				g_param_spec_boxed ("uploaded",
 					"Uploaded", "Specifies the time the video was originally uploaded to YouTube.",
-					G_TYPE_TIME_VAL,
+					GDATA_TYPE_G_TIME_VAL,
 					G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 
 	/**



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/gdata/gdata-query.c b/gdata/gdata-query.c
index ded58f6..7cf0090 100644
--- a/gdata/gdata-query.c
+++ b/gdata/gdata-query.c
@@ -47,7 +47,7 @@ typedef enum {
 	GDATA_QUERY_PARAM_PUBLISHED_MIN = 1 << 5,
 	GDATA_QUERY_PARAM_PUBLISHED_MAX = 1 << 6,
 	GDATA_QUERY_PARAM_START_INDEX = 1 << 7,
-	GDATA_QUERY_PARAM_STRICT = 1 << 8,
+	GDATA_QUERY_PARAM_IS_STRICT = 1 << 8,
 	GDATA_QUERY_PARAM_MAX_RESULTS = 1 << 9,
 	GDATA_QUERY_PARAM_ENTRY_ID = 1 << 10,
 	GDATA_QUERY_PARAM_ALL = (1 << 11) - 1
@@ -69,7 +69,7 @@ struct _GDataQueryPrivate {
 	GTimeVal published_min;
 	GTimeVal published_max;
 	gint start_index;
-	gboolean strict;
+	gboolean is_strict;
 	gint max_results;
 	gchar *entry_id;
 
@@ -90,7 +90,7 @@ enum {
 	PROP_PUBLISHED_MIN,
 	PROP_PUBLISHED_MAX,
 	PROP_START_INDEX,
-	PROP_STRICT,
+	PROP_IS_STRICT,
 	PROP_MAX_RESULTS,
 	PROP_ENTRY_ID,
 	PROP_ETAG
@@ -184,7 +184,7 @@ gdata_query_class_init (GDataQueryClass *klass)
 	g_object_class_install_property (gobject_class, PROP_UPDATED_MIN,
 				g_param_spec_boxed ("updated-min",
 					"Minimum update date", "Minimum date for updates on returned entries.",
-					G_TYPE_TIME_VAL,
+					GDATA_TYPE_G_TIME_VAL,
 					G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 	/**
@@ -195,7 +195,7 @@ gdata_query_class_init (GDataQueryClass *klass)
 	g_object_class_install_property (gobject_class, PROP_UPDATED_MAX,
 				g_param_spec_boxed ("updated-max",
 					"Maximum update date", "Maximum date for updates on returned entries.",
-					G_TYPE_TIME_VAL,
+					GDATA_TYPE_G_TIME_VAL,
 					G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 	/**
@@ -206,7 +206,7 @@ gdata_query_class_init (GDataQueryClass *klass)
 	g_object_class_install_property (gobject_class, PROP_PUBLISHED_MIN,
 				g_param_spec_boxed ("published-min",
 					"Minimum publish date", "Minimum date for returned entries to be published.",
-					G_TYPE_TIME_VAL,
+					GDATA_TYPE_G_TIME_VAL,
 					G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 	/**
@@ -217,7 +217,7 @@ gdata_query_class_init (GDataQueryClass *klass)
 	g_object_class_install_property (gobject_class, PROP_PUBLISHED_MAX,
 				g_param_spec_boxed ("published-max",
 					"Maximum publish date", "Maximum date for returned entries to be published.",
-					G_TYPE_TIME_VAL,
+					GDATA_TYPE_G_TIME_VAL,
 					G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 	/**
@@ -233,13 +233,13 @@ gdata_query_class_init (GDataQueryClass *klass)
 					G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 	/**
-	 * GDataQuery:strict:
+	 * GDataQuery:is-strict:
 	 *
 	 * Strict query parameter checking. If this is enabled, an error will be returned by the online service if a parameter is
 	 * not recognised.
 	 **/
-	g_object_class_install_property (gobject_class, PROP_STRICT,
-				g_param_spec_boolean ("strict",
+	g_object_class_install_property (gobject_class, PROP_IS_STRICT,
+				g_param_spec_boolean ("is-strict",
 					"Strict?", "Should the server be strict about the query?",
 					FALSE,
 					G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
@@ -337,8 +337,8 @@ gdata_query_get_property (GObject *object, guint property_id, GValue *value, GPa
 		case PROP_START_INDEX:
 			g_value_set_int (value, priv->start_index);
 			break;
-		case PROP_STRICT:
-			g_value_set_boolean (value, priv->strict);
+		case PROP_IS_STRICT:
+			g_value_set_boolean (value, priv->is_strict);
 			break;
 		case PROP_MAX_RESULTS:
 			g_value_set_int (value, priv->max_results);
@@ -386,8 +386,8 @@ gdata_query_set_property (GObject *object, guint property_id, const GValue *valu
 		case PROP_START_INDEX:
 			gdata_query_set_start_index (self, g_value_get_int (value));
 			break;
-		case PROP_STRICT:
-			gdata_query_set_strict (self, g_value_get_boolean (value));
+		case PROP_IS_STRICT:
+			gdata_query_set_is_strict (self, g_value_get_boolean (value));
 			break;
 		case PROP_MAX_RESULTS:
 			gdata_query_set_max_results (self, g_value_get_int (value));
@@ -564,7 +564,7 @@ gdata_query_get_query_uri (GDataQuery *self, const gchar *feed_uri)
 		g_string_append_printf (query_uri, "start-index=%d", priv->start_index);
 	}
 
-	if (priv->strict == TRUE) {
+	if (priv->is_strict == TRUE) {
 		APPEND_SEP
 		g_string_append (query_uri, "strict=true");
 	}
@@ -910,40 +910,40 @@ gdata_query_set_start_index (GDataQuery *self, gint start_index)
 }
 
 /**
- * gdata_query_get_strict:
+ * gdata_query_is_strict:
  * @self: a #GDataQuery
  *
- * Gets the #GDataQuery:strict property.
+ * Gets the #GDataQuery:is-strict property.
  *
  * Return value: the strict property
  **/
 gboolean
-gdata_query_get_strict (GDataQuery *self)
+gdata_query_is_strict (GDataQuery *self)
 {
 	g_return_val_if_fail (GDATA_IS_QUERY (self), FALSE);
-	return self->priv->strict;
+	return self->priv->is_strict;
 }
 
 /**
- * gdata_query_set_strict:
+ * gdata_query_set_is_strict:
  * @self: a #GDataQuery
  * @strict: the new strict value
  *
  * Sets the #GDataQuery:strict property of the #GDataQuery to the new strict value, @strict.
  **/
 void
-gdata_query_set_strict (GDataQuery *self, gboolean strict)
+gdata_query_set_is_strict (GDataQuery *self, gboolean is_strict)
 {
 	g_return_if_fail (GDATA_IS_QUERY (self));
 
-	self->priv->strict = strict;
+	self->priv->is_strict = is_strict;
 
-	if (strict == FALSE)
-		self->priv->parameter_mask &= (GDATA_QUERY_PARAM_ALL ^ GDATA_QUERY_PARAM_STRICT);
+	if (is_strict == FALSE)
+		self->priv->parameter_mask &= (GDATA_QUERY_PARAM_ALL ^ GDATA_QUERY_PARAM_IS_STRICT);
 	else
-		self->priv->parameter_mask |= GDATA_QUERY_PARAM_STRICT;
+		self->priv->parameter_mask |= GDATA_QUERY_PARAM_IS_STRICT;
 
-	g_object_notify (G_OBJECT (self), "strict");
+	g_object_notify (G_OBJECT (self), "is-strict");
 }
 
 /**
@@ -910,40 +910,40 @@ gdata_query_set_start_index (GDataQuery *self, gint start_index)
  * @self: a #GDataQuery
- * @strict: the new strict value
+ * @is_strict: the new strict value
  *
@@ -910,40 +910,40 @@ gdata_query_set_start_index (GDataQuery *self, gint start_index)
  *
- * Sets the #GDataQuery:strict property of the #GDataQuery to the new strict value, @strict.
+ * Sets the #GDataQuery:is-strict property of the #GDataQuery to the new strict value, @is_strict.
  **/
 void